@@ -19,7 +19,7 @@ The name of the component group.
 
 =cut
 
-has_xpath_value 'name'           => './@name';
+has_xpath_value 'name'           => './@name', reader => 'get_name';
 
 =head2 defaultOKStatus
 
@@ -28,7 +28,17 @@ have a explicit OKStatus defined in the XML configuration file.
 
 =cut
 
-has_xpath_value 'OKStatus'       => './@defaultOKStatus';
+has_xpath_value 'OKStatus'       => './@defaultOKStatus', reader => 'get_OKStatus';
+
+
+=head2 defaultTaskOKStatus
+
+A string indicating the expected status for all components tasks that are part of this component group. This is used to setup task status of components that do not
+have a explicit TaskOKStatus defined in the XML configuration file.
+
+=cut
+
+has_xpath_value 'taskOKStatus'       => './@defaultTaskOKStatus', reader => 'get_taskOKStatus';
 
 finalize_class();
 __END__
