@@ -1,5 +1,5 @@
 package Siebel::Srvrmgr::Daemon::Heavy;
-$Siebel::Srvrmgr::Daemon::Heavy::VERSION = '0.21';
+$Siebel::Srvrmgr::Daemon::Heavy::VERSION = '0.22';
 =pod
 
 =head1 NAME
@@ -710,7 +710,8 @@ override 'run' => sub {
             else {
 
                 $logger->logdie(
-                    'prompt was not defined from read output, cannot continue');
+"prompt was not defined from read output, cannot continue. Input buffer was: \n"
+                      . Dumper(@input_buffer) );
 
             }
 
